@@ -32,11 +32,7 @@ from arango.exceptions import (
 )
 
 from airflow.exceptions import AirflowException
-
-try:
-    from airflow.sdk import BaseHook
-except ImportError:
-    from airflow.hooks.base import BaseHook  # type: ignore[attr-defined,no-redef]
+from airflow.providers.common.compat.sdk import BaseHook
 
 if TYPE_CHECKING:
     from arango.database import StandardDatabase
